@@ -37,9 +37,9 @@
 #include <string.h>
 
 #include "casu_mods.h"
-#include "casu_utils.h"
+#include "catalogue/casu_utils.h"
 #include "casu_stats.h"
-#include "casu_fits.h"
+#include "catalogue/casu_fits.h"
 
 typedef struct {
     char *filter_name;
