@@ -1,6 +1,7 @@
 /*
  * This file is part of the irplib package
  * Copyright (C) 2002,2003,2014 European Southern Observatory
+ *               2004  Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +32,6 @@
 #include <stdlib.h>
 #include <errno.h>
 
-#include <cpl.h>
-#include <math.h>
-
 /*-----------------------------------------------------------------------------
                            Defines
  -----------------------------------------------------------------------------*/
@@ -544,7 +542,7 @@ cpl_error_code irplib_dfs_product_save(cpl_frameset            * allframes,
     if (!error)
         error = cpl_dfs_setup_product_header(plist, product_frame, usedframes,
                                              parlist, recipe, pipe_id,
-                                             "PRO-1.15", inherit);
+                                             "PRO-1.16", inherit);
 
     if (remregexp != NULL && !error) {
         cpl_errorstate prestate = cpl_errorstate_get();
@@ -1588,7 +1586,7 @@ void * irplib_aligned_malloc(size_t alignment, size_t size)
         size += alignment - (size % alignment);
     }
 
-#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 201112L
+#if defined HAVE_DECL_ALIGNED_ALLOC && defined HAVE_ALIGNED_ALLOC
     return aligned_alloc(alignment, size);
 #elif defined HAVE_POSIX_MEMALIGN && defined HAVE_DECL_POSIX_MEMALIGN
     {
@@ -1668,7 +1666,7 @@ void * irplib_aligned_calloc(size_t alignment, size_t nelem, size_t nbytes)
 /*----------------------------------------------------------------------------*/
 void irplib_aligned_free (void * aligned_ptr)
 {
-#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 201112L
+#if defined HAVE_DECL_ALIGNED_ALLOC && defined HAVE_ALIGNED_ALLOC
   free(aligned_ptr);
 #elif defined HAVE_POSIX_MEMALIGN && defined HAVE_DECL_POSIX_MEMALIGN
   free(aligned_ptr);
@@ -1725,3 +1723,82 @@ irplib_frameset_get_next_const(cpl_frameset_iterator *iterator)
     }
     return cpl_frameset_iterator_get_const(iterator);
 }
+
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief  Find the kth smallest value in a cpl_vector
+  @param  self The vector to permute and search
+  @param  k    The requested value position in the sorted array, zero for 1st
+
+  After a successful call, self is permuted so elements less than the kth have
+  lower indices, while elements greater than the kth have higher indices. If
+  the call fails, self is not modified.
+
+  Reference:
+
+  Author: Wirth, Niklaus 
+  Title: Algorithms + data structures = programs 
+  Publisher: Englewood Cliffs: Prentice-Hall, 1976 
+  Physical description: 366 p. 
+  Series: Prentice-Hall Series in Automatic Computation 
+
+  See also: http://ndevilla.free.fr/median/median/
+
+ */
+/*----------------------------------------------------------------------------*/
+
+void irplib_vector_get_kth(cpl_vector * self, cpl_size k)
+{
+
+    cpl_size l = 0;
+    cpl_size m = cpl_vector_get_size(self) - 1;
+    cpl_size i = l;
+    cpl_size j = m;
+    double*  pself = cpl_vector_get_data(self);
+
+    if (pself == NULL) {
+        (void)cpl_error_set(cpl_func, CPL_ERROR_NULL_INPUT);
+        return;
+    } else if (k < 0) {
+        (void)cpl_error_set(cpl_func, CPL_ERROR_ILLEGAL_INPUT);
+        return;
+    } else if (k > m) {
+        (void)cpl_error_set(cpl_func, CPL_ERROR_ACCESS_OUT_OF_RANGE);
+        return;
+    }
+
+    while (l < m) {
+        const double x = pself[k];
+
+        do {
+            while (pself[i] < x) i++;
+            while (x < pself[j]) j--;
+            if (i <= j) {
+                IRPLIB_SWAP_DOUBLE(pself[i], pself[j]);
+                i++; j--;
+            }
+        } while (i <= j);
+
+        assert( j < i );
+
+        /* The original implementation has two index comparisons and
+           two, three or four index assignments. This has been reduced
+           to one or two index comparisons and two index assignments.
+        */
+
+        if (k <= j) {
+            assert( k < i );
+            m = j;
+            i = l;
+        } else {
+            if (k < i) {
+                m = j;
+            } else {
+                j = m;
+            }
+            l = i;
+        }
+    }
+}
