@@ -85,14 +85,14 @@ typedef struct _PIL_CDB_VALUE_ {
 typedef PilDictNode PilCdbGroup;
 typedef PilDictNode PilCdbEntry;
 
-inline static void deletePilCdbGroup(PilCdbGroup *, void *);
-inline static void deletePilCdbEntry(PilCdbEntry *, void *);
-inline static int pilCdbAddGroup(PilCdb *, const char *);
-inline PilCdbKeyCase pilCdbGetKeyCase(const PilCdb *);
-inline char pilCdbGetGroupIFS(const PilCdb *db);
+ static void deletePilCdbGroup(PilCdbGroup *, void *);
+ static void deletePilCdbEntry(PilCdbEntry *, void *);
+ static int pilCdbAddGroup(PilCdb *, const char *);
+ PilCdbKeyCase pilCdbGetKeyCase(const PilCdb *);
+ char pilCdbGetGroupIFS(const PilCdb *db);
 
 
-inline static int keycmp(const void *keyword1, const void *keyword2)
+ static int keycmp(const void *keyword1, const void *keyword2)
 {
   return strcmp(keyword1, keyword2);
 }
@@ -112,7 +112,7 @@ inline static int keycmp(const void *keyword1, const void *keyword2)
  * memory can be deallocated using pil_free(). It is a private function.
  */
 
-inline static char *db_create_name(PilCdb *db, const char *name)
+ static char *db_create_name(PilCdb *db, const char *name)
 {
 
   char *db_key;
@@ -147,7 +147,7 @@ inline static char *db_create_name(PilCdb *db, const char *name)
  * read only flag. It is a private function.
  */
 
-inline static PilCdbValue *newPilCdbValue(const char *value, 
+ static PilCdbValue *newPilCdbValue(const char *value, 
 					  PilCdbKeyMode read_only)
 {
 
@@ -181,7 +181,7 @@ inline static PilCdbValue *newPilCdbValue(const char *value,
  * nothing is done. It is a private function.
  */
 
-inline static void deletePilCdbValue(PilCdbValue *db_data)
+ static void deletePilCdbValue(PilCdbValue *db_data)
 {
 
   if (db_data) {
@@ -206,7 +206,7 @@ inline static void deletePilCdbValue(PilCdbValue *db_data)
  * database value object is not allocated. It is a private function.
  */
 
-inline static PilCdbEntry *newPilCdbEntry(void *context)
+ static PilCdbEntry *newPilCdbEntry(void *context)
 {
   (void)context;
   return newPilDictNode(NULL);
@@ -224,7 +224,7 @@ inline static PilCdbEntry *newPilCdbEntry(void *context)
  * and value field, if the fields are used.
  */
 
-inline static void deletePilCdbEntry(PilCdbEntry *db_entry, void *context)
+ static void deletePilCdbEntry(PilCdbEntry *db_entry, void *context)
 {
 
   (void)context;
@@ -264,7 +264,7 @@ inline static void deletePilCdbEntry(PilCdbEntry *db_entry, void *context)
  * is created. It is a private function.
  */
 
-inline static PilCdbGroup *newPilCdbGroup(void *context)
+ static PilCdbGroup *newPilCdbGroup(void *context)
 {
 
   (void)context;
@@ -298,7 +298,7 @@ inline static PilCdbGroup *newPilCdbGroup(void *context)
  * and all group entries, if they are present.
  */
 
-inline static void deletePilCdbGroup(PilCdbGroup *db_group, void *context)
+ static void deletePilCdbGroup(PilCdbGroup *db_group, void *context)
 {
 
   (void)context;
@@ -347,7 +347,7 @@ inline static void deletePilCdbGroup(PilCdbGroup *db_group, void *context)
  * database value. It is a private function.
  */
 
-inline static PilCdbKeyMode pilCdbGetMode(PilCdbValue *db_value)
+ static PilCdbKeyMode pilCdbGetMode(PilCdbValue *db_value)
 {
 
   return db_value->read_only;
@@ -368,7 +368,7 @@ inline static PilCdbKeyMode pilCdbGetMode(PilCdbValue *db_value)
  * @em mode. Allowed values are @c READ_WRITE or @c READ_ONLY.
  */
 
-inline static void pilCdbSetMode(PilCdbValue *db_value, PilCdbKeyMode mode)
+ static void pilCdbSetMode(PilCdbValue *db_value, PilCdbKeyMode mode)
 {
 
   db_value->read_only = mode;
@@ -392,7 +392,7 @@ inline static void pilCdbSetMode(PilCdbValue *db_value, PilCdbKeyMode mode)
  * It is a private function.
  */
 
-inline static int pilCdbSetValue(PilCdbValue *db_value, const char *value,
+ static int pilCdbSetValue(PilCdbValue *db_value, const char *value,
 				 PilCdbKeyMode mode)
 {
 
@@ -439,7 +439,7 @@ inline static int pilCdbSetValue(PilCdbValue *db_value, const char *value,
  * pointer is returned. It is a private function.
  */
 
-inline static PilCdbGroup *pilCdbFindGroup(PilCdb *db, const char *group)
+ static PilCdbGroup *pilCdbFindGroup(PilCdb *db, const char *group)
 {
 
   char *db_group_name;
@@ -479,7 +479,7 @@ inline static PilCdbGroup *pilCdbFindGroup(PilCdb *db, const char *group)
  * private function.
  */
 
-inline static int pilCdbAddGroup(PilCdb *db, const char *group)
+ static int pilCdbAddGroup(PilCdb *db, const char *group)
 {
 
   PilCdbGroup *db_group;
@@ -556,7 +556,7 @@ inline static int pilCdbAddGroup(PilCdb *db, const char *group)
  * a private function.
  */
 
-inline static PilCdbEntry *pilCdbFindEntry(PilCdb *db, PilCdbGroup *db_group,
+ static PilCdbEntry *pilCdbFindEntry(PilCdb *db, PilCdbGroup *db_group,
 					   const char *name)
 {
 
@@ -725,7 +725,7 @@ static int pilCdbAddEntry(PilCdb *db, const char *group, const char *name,
  * function returns an error.
  */
 
-inline static int pilCdbDumpGroup(PilCdbGroup *db_group, FILE *file)
+ static int pilCdbDumpGroup(PilCdbGroup *db_group, FILE *file)
 {
   PilCdbEntry *db_entry;
   PilCdbValue *db_data;
@@ -780,7 +780,7 @@ inline static int pilCdbDumpGroup(PilCdbGroup *db_group, FILE *file)
 }
 
 
-inline static char **pilCdbDumpGrouptoString(PilCdbGroup *db_group, int *n)
+ static char **pilCdbDumpGrouptoString(PilCdbGroup *db_group, int *n)
 {
   PilCdbEntry *db_entry;
   PilCdbValue *db_data;
@@ -940,7 +940,7 @@ void deletePilCdb(PilCdb *db)
  * @see pilCdbSetGroupIFS()
  */
 
-inline char pilCdbGetGroupIFS(const PilCdb *db)
+ char pilCdbGetGroupIFS(const PilCdb *db)
 {
 
   return db->grp_ifs;
@@ -966,7 +966,7 @@ inline char pilCdbGetGroupIFS(const PilCdb *db)
  * @see pilCdbGetGroupIFS()
  */
 
-inline int pilCdbSetGroupIFS(PilCdb *db, char ifs)
+ int pilCdbSetGroupIFS(PilCdb *db, char ifs)
 {
 
   if (!pilDictIsEmpty(db->groups))
@@ -995,7 +995,7 @@ inline int pilCdbSetGroupIFS(PilCdb *db, char ifs)
  * @see pilCdbSetKeyCase()
  */
 
-inline PilCdbKeyCase pilCdbGetKeyCase(const PilCdb *db)
+ PilCdbKeyCase pilCdbGetKeyCase(const PilCdb *db)
 {
 
   return db->key_case;
@@ -1021,7 +1021,7 @@ inline PilCdbKeyCase pilCdbGetKeyCase(const PilCdb *db)
  * @see newPilCdb()
  */
 
-inline int pilCdbSetKeyCase(PilCdb *db, PilCdbKeyCase mode)
+ int pilCdbSetKeyCase(PilCdb *db, PilCdbKeyCase mode)
 {
 
   if (!pilDictIsEmpty(db->groups))
