@@ -35,6 +35,13 @@
 #include <assert.h>
 #include <string.h>
 
+/*-----------------------------------------------------------------------------
+                                Defines
+ -----------------------------------------------------------------------------*/
+
+#define HDRL_MSG  "Imagelist with %d image(s)\n"
+#define HDRL_IMSG "Image nb %d of %d in imagelist\n"
+
 /*-----------------------------------------------------------------------------
                             Static Prototypes
  -----------------------------------------------------------------------------*/
@@ -399,21 +406,22 @@ void hdrl_imagelist_empty(hdrl_imagelist * himlist)
 {
     if (himlist != NULL) {
         while (himlist->ni > 0) { /* An iteration may unset more than 1 image */
-            cpl_size i = himlist->ni - 1;
-            hdrl_image * del = hdrl_imagelist_unset(himlist, i);
-            hdrl_image_delete(del);
+
+        	cpl_size i = himlist->ni - 1;
+            hdrl_image *del = hdrl_imagelist_unset(himlist, i);
 
             /* If this image was inserted more than once into the list,
                the other insertions must be unset without a delete. */
             while (--i >= 0) {
                 if (himlist->images[i] == del) {
                     /* This image was inserted more than once in the list */
-                    (void)hdrl_imagelist_unset(himlist, i);
+                    del = hdrl_imagelist_unset(himlist, i);
                 }
             }
+
+            hdrl_image_delete(del);
         }
     }
-    return;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -485,23 +493,21 @@ cpl_error_code hdrl_imagelist_dump_structure(
         const hdrl_imagelist    *   himlist,
         FILE                    *   stream)
 {
-    const char * msg    = "Imagelist with %d image(s)\n";
-    const int    msgmin = (int)strlen(msg) - 5;
+    const int    msgmin = (int)strlen(HDRL_MSG) - 5;
 
     int i;
 
     cpl_ensure_code(himlist   != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(stream != NULL, CPL_ERROR_NULL_INPUT);
 
-    cpl_ensure_code( fprintf(stream,  msg, himlist->ni) >= msgmin,
+    cpl_ensure_code( fprintf(stream,  HDRL_MSG, (int)himlist->ni) >= msgmin,
              CPL_ERROR_FILE_IO );
 
     for (i = 0; i < himlist -> ni; i++) {
     const hdrl_image    *   image   = hdrl_imagelist_get_const(himlist, i);
-    const char          *   imsg    = "Image nb %d of %d in imagelist\n";
-    const int               imsgmin = (int)strlen(imsg) - 5;
+    const int               imsgmin = (int)strlen(HDRL_IMSG) - 5;
 
-    cpl_ensure_code( fprintf(stream,  imsg, i, himlist->ni) >= imsgmin,
+    cpl_ensure_code( fprintf(stream, HDRL_IMSG, i, (int)himlist->ni) >= imsgmin,
              CPL_ERROR_FILE_IO );
 
     cpl_ensure_code( !hdrl_image_dump_structure(image, stream),
@@ -544,11 +550,10 @@ cpl_error_code hdrl_imagelist_dump_window(
 
     for (i = 0; i < himlist -> ni; i++) {
     const hdrl_image    *   image   = hdrl_imagelist_get_const(himlist, i);
-    const char          *   imsg    = "Image nb %d of %d in imagelist\n";
-    const int               imsgmin = (int)strlen(imsg) - 5;
+    const int               imsgmin = (int)strlen(HDRL_IMSG) - 5;
 
-    cpl_ensure_code( fprintf(stream,  imsg, i, himlist->ni) >= imsgmin,
-             CPL_ERROR_FILE_IO );
+    cpl_ensure_code( fprintf(stream,  HDRL_IMSG, (int)i,
+                             (int)himlist->ni) >= imsgmin, CPL_ERROR_FILE_IO );
 
     cpl_ensure_code( !hdrl_image_dump_window(image, llx, lly, urx, ury,
                            stream),
@@ -581,8 +586,10 @@ void hdrl_imagelist_unwrap(hdrl_imagelist * himlist)
 typedef struct {
     const hdrl_imagelist * hlist;
     cpl_size ny;
+    cpl_size prev_pos;
     cpl_size pos;
     cpl_size nrows;
+    cpl_size overlap;
     hdrl_imagelist * last_view;
 } hdrl_imagelist_row_slices_iter;
 
@@ -592,41 +599,59 @@ static void * hdrl_imagelist_row_slices_next(hdrl_iter * it)
     if (s->pos > s->ny) {
         return NULL;
     }
-    cpl_size upper = CX_MIN(s->pos + s->nrows - 1, s->ny);
+    cpl_size lower = CX_MAX(s->pos - s->overlap, 1);
+    cpl_size upper = CX_MIN(s->pos + s->nrows + s->overlap - 1, s->ny);
     /* const iterator means you cannot modify the data but the created views
      * can have a NULL bpm which can be faster e.g. when calling
      * cpl_image_new_from_accepted on the view */
     /* TODO could set memory readonly? */
     hdrl_imagelist * view;
+
+    CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
     if (hdrl_iter_check(it, HDRL_ITER_CONST)) {
         view = (hdrl_imagelist*)
             hdrl_imagelist_const_row_view((hdrl_imagelist*)s->hlist,
-                                          s->pos, upper);
+                                          lower, upper);
     }
     else {
         view = hdrl_imagelist_row_view((hdrl_imagelist*)s->hlist,
-                                       s->pos, upper);
+                                       lower, upper);
     }
+    CPL_DIAG_PRAGMA_POP;
 
-    s->pos = upper + 1;
-    if (hdrl_iter_check(it, HDRL_ITER_OWN_OUTPUT)) {
+    s->prev_pos = s->pos;
+    s->pos = CX_MIN(s->pos + s->nrows - 1, s->ny) + 1;
+    if (hdrl_iter_check(it, HDRL_ITER_OWNS_DATA)) {
         hdrl_imagelist_delete(s->last_view);
         s->last_view = view;
     }
     return view;
 }
 
+hdrl_il_rowsliceiter_data
+hdrl_imagelist_iter_row_slices_get_data(const hdrl_iter * it)
+{
+    hdrl_imagelist_row_slices_iter * s = hdrl_iter_state(it);
+
+    if (s->prev_pos == 1) {
+        return (hdrl_il_rowsliceiter_data){1., CX_MIN(s->nrows, s->ny)};
+    }
+    else {
+        return (hdrl_il_rowsliceiter_data){s->overlap + 1, s->overlap + s->pos - s->prev_pos};
+    }
+}
+
 static cpl_size hdrl_imagelist_row_slices_length(hdrl_iter * it)
 {
     hdrl_imagelist_row_slices_iter * s = hdrl_iter_state(it);
     return s->ny / s->nrows + ((s->ny % s->nrows) != 0);
 }
 
-static void hdrl_imagelist_iter_delete(void * state)
+static void hdrl_imagelist_iter_delete(void * it)
 {
-    if (!state)
+    if (!it)
         return;
-    hdrl_imagelist_row_slices_iter * s = state;
+    hdrl_imagelist_row_slices_iter * s = hdrl_iter_state(it);
     hdrl_imagelist_delete(s->last_view);
     cpl_free(s);
 }
@@ -634,7 +659,8 @@ static void hdrl_imagelist_iter_delete(void * state)
 /* TODO, add offset and stride for parallel processing? or imagelist_split? */
 hdrl_iter * hdrl_imagelist_get_iter_row_slices(const hdrl_imagelist * hlist,
                                                  cpl_size nrows,
-                                                 hdrl_iter_type_t flags)
+                                                 cpl_size overlap,
+                                                 hdrl_iter_flags flags)
 {
     cpl_ensure(hlist, CPL_ERROR_NULL_INPUT, NULL);
     /* 0 accepted for now, could mean choosen by function */
@@ -645,7 +671,9 @@ hdrl_iter * hdrl_imagelist_get_iter_row_slices(const hdrl_imagelist * hlist,
     hdrl_imagelist_row_slices_iter * state = cpl_malloc(sizeof(*state));
     state->hlist = hlist;
     state->ny = hdrl_imagelist_get_size_y(hlist);
+    state->prev_pos = 1;
     state->pos = 1;
+    state->overlap = CX_MAX(overlap, 0);
     state->nrows = CX_MAX(nrows, 1);
     state->last_view = NULL;
 
