@@ -488,6 +488,18 @@ static int vimos_calib_create(cpl_plugin *plugin)
     cpl_parameterlist_append(recipe->parameters, p);
 
 
+    p = cpl_parameter_new_value("vimos.vmmoscalib.normalise_spa_local",
+                                CPL_TYPE_BOOL,
+                                "If TRUE the normalization along the "
+                                "spatial axis is performed row-by-row "
+                                "otherwise a collapsed slit is used.",
+                                "vimos.vmmoscalib",
+                                TRUE);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "normalise_spa_local");
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(recipe->parameters, p);
+
+
     return 0;
 }
 
