@@ -66,8 +66,9 @@
 #include "vmimgutils.h"
 #include "vmqcutils.h"
 #include "vmcpl.h"
-#include "VimosIfuWCS.h"
-#include "VimosUtils.h"
+#include "vimos_ifu_wcs.h"
+#include "vimos_utils.h"
+#include "vimos_dfs.h"
 
 /*-----------------------------------------------------------------------------
                             Functions prototypes
@@ -499,7 +500,7 @@ vmifucombinecube(PilSetOfFrames *sof)
     if (i) {
       if (strcmp(tplStart, astart)) {
         if (warning) {
-          cpl_msg_warning(task, warning);
+          cpl_msg_warning(task, "%s", warning);
           warning = NULL;                       /* Print just once */
         }
       }
@@ -701,7 +702,8 @@ vmifucombinecube(PilSetOfFrames *sof)
    * update the set of frames.
    */
 
-  strlower(strcpy(cubeName, cubeTag));
+  cpl_msg_info(cpl_func, "Saving the cube...");
+  vmstrlower(strcpy(cubeName, cubeTag));
   strcat(cubeName, ".fits");
 
 
@@ -740,29 +742,31 @@ cpl_propertylist * vimos_ifu_combinecube_add_wcs
     double dec_vimos;
     double epoch;
     double equinox;
-    double plateScale;
-    double posAngle;
+    double plate_scale;
+    double pos_angle_ins;
+    double pos_angle_wcs;
     cpl_propertylist * wcsheader;
     PilFrame *wcs_ref_frame = pilSofFirst((PilSetOfFrames *)sof);
     
-    if((VimosCheckEqualKeys(sof, inputTag, "ESO TEL TARG ALPHA", alpha_target) &&
-        VimosCheckEqualKeys(sof, inputTag, "ESO TEL TARG DELTA", delta_target) &&
-        VimosCheckEqualKeys(sof, inputTag, "RA", ra_vimos) &&
-        VimosCheckEqualKeys(sof, inputTag, "DEC", dec_vimos) &&
-        VimosCheckEqualKeys(sof, inputTag, "ESO TEL TARG EPOCH", epoch) &&
-        VimosCheckEqualKeys(sof, inputTag, "ESO TEL TARG EQUINOX", equinox) &&
-        VimosCheckEqualKeys(sof, inputTag, "ESO INS PIXSCALE", plateScale) &&
-        VimosCheckEqualKeys(sof, inputTag, "ESO ADA POSANG", posAngle)))
+    if((vimos_check_equal_keys(sof, inputTag, "ESO TEL TARG ALPHA", alpha_target) &&
+        vimos_check_equal_keys(sof, inputTag, "ESO TEL TARG DELTA", delta_target) &&
+        vimos_check_equal_keys(sof, inputTag, "RA", ra_vimos) &&
+        vimos_check_equal_keys(sof, inputTag, "DEC", dec_vimos) &&
+        vimos_check_equal_keys(sof, inputTag, "ESO TEL TARG EPOCH", epoch) &&
+        vimos_check_equal_keys(sof, inputTag, "ESO TEL TARG EQUINOX", equinox) &&
+        vimos_check_equal_keys(sof, inputTag, "ESO INS PIXSCALE", plate_scale) &&
+        vimos_check_equal_keys(sof, inputTag, "ESO ADA POSANG", pos_angle_ins)))
     {
         cpl_msg_info(cpl_func,"Adding WCS information to the cube");
 
         cpl_propertylist * header;
         header = cpl_propertylist_load(pilFrmGetName(wcs_ref_frame),0);
+        pos_angle_wcs = - (pos_angle_ins + 90);
         
-        TwoDLinearWCS spatial_wcs = 
-                VimosIfuGet2DWCSFromPointing(ra_vimos, dec_vimos, 
-                posAngle, nx_fiber+1, ny_fiber+1, 
-                plateScale, epoch, equinox);
+        two_d_linear_wcs spatial_wcs = 
+                vimos_ifu_get_2d_wcs_from_pointing(ra_vimos, dec_vimos, 
+                pos_angle_wcs, nx_fiber+1, ny_fiber+1, 
+                plate_scale, epoch, equinox);
 
         wcsheader = cpl_propertylist_new();
         cpl_propertylist_update_double(wcsheader, "CRPIX1", spatial_wcs.crpix1());
@@ -774,10 +778,10 @@ cpl_propertylist * vimos_ifu_combinecube_add_wcs
         cpl_propertylist_update_double(wcsheader, "CDELT1", spatial_wcs.cdelt1());
         cpl_propertylist_update_double(wcsheader, "CDELT2", spatial_wcs.cdelt2());
         cpl_propertylist_update_double(wcsheader, "CDELT3", spec_cdelt1);
-        cpl_propertylist_update_double(wcsheader, "CD1_1",  spatial_wcs.cdMatrix()[0]);
-        cpl_propertylist_update_double(wcsheader, "CD1_2",  spatial_wcs.cdMatrix()[1]);
-        cpl_propertylist_update_double(wcsheader, "CD2_1",  spatial_wcs.cdMatrix()[2]);
-        cpl_propertylist_update_double(wcsheader, "CD2_2",  spatial_wcs.cdMatrix()[3]);
+        cpl_propertylist_update_double(wcsheader, "CD1_1",  spatial_wcs.cd_matrix()[0]);
+        cpl_propertylist_update_double(wcsheader, "CD1_2",  spatial_wcs.cd_matrix()[1]);
+        cpl_propertylist_update_double(wcsheader, "CD2_1",  spatial_wcs.cd_matrix()[2]);
+        cpl_propertylist_update_double(wcsheader, "CD2_2",  spatial_wcs.cd_matrix()[3]);
         cpl_propertylist_update_string(wcsheader, "CTYPE1", spatial_wcs.ctype1().c_str());
         cpl_propertylist_update_string(wcsheader, "CTYPE2", spatial_wcs.ctype2().c_str());
         cpl_propertylist_update_string(wcsheader, "CTYPE3", "WAVE");
