@@ -1,4 +1,6 @@
 # import the needed modules
+from __future__ import absolute_import
+from __future__ import print_function
 try:
   import reflex
   import matplotlib.gridspec
@@ -195,17 +197,17 @@ a constant shift (--skyalign parameter)."""
         
         # Multiplexing Selector radiobutton
         self.keys = dict()
-	labels = []
+        labels = []
         for i in range(1, len(self.sci_mapped.mappedsciences)+1) :
-	  label = self.no_flux_cal_label + str(i)
+          label = self.no_flux_cal_label + str(i)
           self.keys[label] = [i, False]
-	  labels.append(label)
+          labels.append(label)
 
-	if self.has_flux_cal:
-	        for i in range(1, len(self.sci_mapped.mappedsciences)+1) :
-		  label = self.flux_cal_label + str(i)
-		  self.keys[label] = [i, True]
-		  labels.append(label)
+        if self.has_flux_cal:
+          for i in range(1, len(self.sci_mapped.mappedsciences)+1) :
+            label = self.flux_cal_label + str(i)
+            self.keys[label] = [i, True]
+            labels.append(label)
 
         self.radiomplex_flux_not_cal =  InteractiveRadioButtons(self.subplot_mplex_select_flux_not_cal, 
             self.setMultiplexing, labels, 0, title='Mplex')
@@ -270,7 +272,7 @@ In this window, the user will interact with the Vimos science reduction"""
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
 
 #This is the 'main' function
 if __name__ == '__main__':
