@@ -99,6 +99,13 @@ cpl_table *mos_build_disp_coeff(cpl_table *, cpl_table *);
 cpl_table *mos_wavelength_align(cpl_image *, cpl_table *, double, double,
                                 double, cpl_table *, cpl_vector *, int, 
                                 int, cpl_image *, int);
+
+cpl_table * mos_wavelength_align_get_offsets(const double firstLambda,
+        const double lastLambda,
+        const double refwave, const int sradius,
+        const cpl_vector * skylines, int highres, const cpl_table * idscoeff,
+        const cpl_table * slits, const cpl_image * image);
+
 cpl_table *mos_wavelength_align_lss(cpl_image *, double, double, double,
                               cpl_table *, cpl_vector *, int, int, 
                               cpl_image *, int);
