@@ -46,9 +46,9 @@
 #include "vimos_detmodel.h"
 #include "vimos_flat_normalise.h"
 #include "flat_combine.h"
+#include "vimos_spec_idp.h"
 
-
-std::auto_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
+std::unique_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
 (vimos::calibrated_slits& calibrated_slits, 
  const mosca::wavelength_calibration& wave_cal,
  const mosca::grism_config& grism_cfg,
@@ -58,21 +58,31 @@ std::auto_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
  const char * flat_tag);
 
 int vimos_calib_flats_save
-(std::auto_ptr<mosca::image>& master_flat_d, 
- std::auto_ptr<mosca::image>& norm_flat,
+(mosca::image& master_flat_d, 
+ std::unique_ptr<mosca::image>& norm_flat,
  cpl_frameset * frameset, const char * flat_tag, 
  const char * master_screen_flat_tag, const char * master_norm_flat_tag, 
  cpl_parameterlist * parlist, cpl_propertylist * qc_list);
 
+static
 cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat, 
                                       cpl_table * slits,
                                       int nx, int ny, int nflats,
                                       mosca::grism_config& grism_cfg,
                                       double alltime, double xwidth,
                                       double ywidth, double gain, 
-                                      double focu_scale);
+                                      double focu_scale,
+									  double resolution,
+									  int nwaves,
+									  double accuracy);
 
 
+
+static bool get_has_reference_slits(const cpl_propertylist * l);
+
+static bool
+get_has_curved_slits(const cpl_propertylist * l);
+
 #define vimos_calib_exit(message)             \
 {                                             \
 if ((const char *)message != NULL) cpl_msg_error(recipe, message);  \
@@ -182,6 +192,7 @@ return 0;                                       \
 
 /**@{*/
 
+
 /**
  * @brief    Interpret the command line options and execute the data processing
  *
@@ -446,6 +457,9 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     
     disp_tolerance = 0.2; 
             
+    const bool normalise_spa_local = dfs_get_parameter_bool(parlist,
+                    "vimos.vmmoscalib.normalise_spa_local", NULL);
+
     if (cpl_error_get_code())
         vimos_calib_exit("Failure getting the configuration parameters");
 
@@ -552,7 +566,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     if (cpl_error_get_code() != CPL_ERROR_NONE)
         vimos_calib_exit("Missing keyword EXPTIME in flat field frame header");
 
-    cpl_propertylist_delete(header);
+    cpl_propertylist_delete(header); header = NULL;
 
     for (i = 1; i < nflats; i++) {
 
@@ -567,7 +581,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
             vimos_calib_exit("Missing keyword EXPTIME in flat field "
                             "frame header");
 
-        cpl_propertylist_delete(header);
+        cpl_propertylist_delete(header); header = NULL;
 
     }
 
@@ -704,7 +718,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
 
     xwidth = cpl_table_get(maskslits, "xwidth", cslit, NULL);
     ywidth = cpl_table_get(maskslits, "ywidth", cslit, NULL);
-
+    const double median_y_width = cpl_table_get_column_median(maskslits, "ywidth");
     /*
      * Check if all slits have the same X offset: in such case, 
      * treat the observation as a long-slit one!
@@ -720,12 +734,11 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
             treat_as_lss = 0;
             break;
         }
-        cpl_propertylist * ref_slits = cpl_propertylist_new();
-        cpl_propertylist_copy_property_regexp(ref_slits, arc_header, "ESO INS REF", 0);
-        bool reference_slits_present = (cpl_propertylist_get_size(ref_slits) > 0); 
-        if(nslits == 1 && reference_slits_present)
+        const bool has_reference_slits = get_has_reference_slits(arc_header);
+        const bool has_curved_slits = get_has_curved_slits(arc_header);
+
+        if(nslits == 1 && has_reference_slits && has_curved_slits)
             treat_as_lss = 0;
-        cpl_propertylist_delete(ref_slits);
     }
 
     if (treat_as_lss) {
@@ -870,7 +883,8 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
          * This is necessary to move on to a many-slits solution
          */
 
-        mos_refmask_find_gaps(refmask, master_flat, 5000.);
+        if(mos_refmask_find_gaps(refmask, master_flat, 5000.))
+            vimos_calib_exit("Unable to find gaps in the reference wavelength mask.");
 
 
         cpl_table_wrap_double(idscoeff, fiterror, "error"); fiterror = NULL;
@@ -1035,6 +1049,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
         }
         else {
             compute_global = 0;
+            slit_ident = 0;
             cpl_msg_info(recipe, "Global distortion model cannot be computed");
             if (cpl_error_get_code() != CPL_ERROR_NONE) {
                 vimos_calib_exit(NULL);
@@ -1094,6 +1109,14 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
                          "contained in CCD", nslits);
 
         }
+        else {
+            compute_global = 0;
+            slit_ident = 0;
+            cpl_msg_info(recipe, "Global distortion model cannot be computed");
+            if (cpl_error_get_code() != CPL_ERROR_NONE) {
+                vimos_calib_exit(NULL);
+            }
+        }
     }
 
 
@@ -1134,6 +1157,10 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
                                       startwavelength, endwavelength, 
                                       dispersion, 0, coordinate);
 
+    if(!spatial){
+        vimos_calib_exit("Unable to perform spatial calibration");
+    }
+
     /*
      * Final wavelength calibration of spectra having their curvature
      * removed
@@ -1303,6 +1330,8 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     mean_rms = mos_distortions_rms(rectified, lines, startwavelength, 
                                    dispersion, 6, 0);
 
+    const double accuracy_nm = mean_rms * dispersion / 10.0;
+
     cpl_msg_info(recipe, "Mean residual: %f pixel", mean_rms);
 
     mean_rms = cpl_table_get_column_mean(idscoeff, "error");
@@ -1310,12 +1339,12 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     cpl_msg_info(recipe, "Mean model accuracy: %f pixel (%f A)", 
                  mean_rms, mean_rms * dispersion);
 
-    restab = mos_resolution_table(rectified, startwavelength, dispersion, 
+    restab = mos_resolution_table(rectified, startwavelength, dispersion,
                                   60000, lines);
 
     if (restab) {
-        cpl_msg_info(recipe, "Mean spectral resolution: %.2f", 
-                   cpl_table_get_column_mean(restab, "resolution"));
+        cpl_msg_info(recipe, "Mean spectral resolution: %.2f",
+        		cpl_table_get_column_mean(restab, "resolution"));
         cpl_msg_info(recipe, "Mean reference lines FWHM: %.2f +/- %.2f pixel",
                    cpl_table_get_column_mean(restab, "fwhm") / dispersion,
                    cpl_table_get_column_mean(restab, "fwhm_rms") / dispersion);
@@ -1329,6 +1358,11 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     else
         vimos_calib_exit("Cannot compute the spectral resolution table");
 
+    const double qc_resolution = cpl_table_get_column_mean(restab,
+            "resolution");
+    const int qc_nwaves = cpl_table_get_nrow(restab);
+
+
     cpl_vector_delete(lines); lines = NULL;
 
     /*
@@ -1853,7 +1887,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     cpl_msg_indent_less();
     cpl_msg_info(recipe, "Perform flat field combination...");
     
-    std::auto_ptr<mosca::image> master_flat_d;
+    std::unique_ptr<mosca::image> master_flat_d;
     std::auto_ptr<mosca::fiera_config> ccd_config;
     master_flat_d = vimos_calib_flat_mos_create_master_flat(calib_slits,
             wave_cal, *grism_cfg, master_bias, master_bias_err,
@@ -1868,7 +1902,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     cpl_msg_info(recipe, "Perform flat field normalisation...");
     cpl_msg_indent_more();
 
-    std::auto_ptr<mosca::image> norm_flat;
+    std::unique_ptr<mosca::image> norm_flat;
     norm_flat.reset(new mosca::image(cpl_image_cast(master_flat_d->get_cpl_image(), 
                                                     CPL_TYPE_FLOAT),
                                      cpl_image_cast(master_flat_d->get_cpl_image_err(), 
@@ -1879,15 +1913,17 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
                              coordinate, calib_slits, slits, polytraces,
                              startwavelength, endwavelength,
                              dispersion, sradius, dradius,
-                             spa_polyorder, disp_nknots, fit_threshold);
+                             spa_polyorder, disp_nknots,
+                             fit_threshold, normalise_spa_local);
     if( cpl_error_get_code() != CPL_ERROR_NONE)
         vimos_calib_exit("Cannot normalize master flat");
     
     //Saving the flats
     cpl_propertylist * qc_list = vimos_calib_flat_qc(*master_flat_d,
              slits, nx, ny, nflats, *grism_cfg, alltime, xwidth, ywidth, 
-             gain, scale);
-    vimos_calib_flats_save(master_flat_d,  norm_flat, frameset, flat_tag, 
+             gain, scale, qc_resolution, qc_nwaves, accuracy_nm);
+
+    vimos_calib_flats_save(*master_flat_d,  norm_flat, frameset, flat_tag, 
                            master_screen_flat_tag, master_norm_flat_tag, 
                            parlist, qc_list);
 
@@ -1908,8 +1944,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
         if(slit_ident) //If slit identification failed, the pipeline fails.
             slit_widths.push_back(cpl_table_get_double(slits, "ywidth", i_slit, &null));
         else
-            slit_widths.push_back(1);
-
+            slit_widths.push_back(median_y_width);
     }
     sed_norm = normaliser.get_wave_profiles_norm(alltime, 
                                                  slit_widths, slit_lengths);
@@ -2043,7 +2078,7 @@ int vimos_calib_impl(cpl_frameset *frameset, cpl_parameterlist *parlist)
     return 0;
 }
 
-std::auto_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
+std::unique_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
 (vimos::calibrated_slits& calibrated_slits, 
  const mosca::wavelength_calibration& wave_cal,
  const mosca::grism_config& grism_cfg,
@@ -2054,7 +2089,7 @@ std::auto_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
 {
     const char     * recipe_name = "fors_calib";
     cpl_errorstate   error_prevstate = cpl_errorstate_get();
-    std::auto_ptr<mosca::image> master_flat;
+    std::unique_ptr<mosca::image> master_flat;
 
     cpl_msg_indent_more();
 
@@ -2152,8 +2187,8 @@ std::auto_ptr<mosca::image> vimos_calib_flat_mos_create_master_flat
 }
 
 int vimos_calib_flats_save
-(std::auto_ptr<mosca::image>& master_flat_d, 
- std::auto_ptr<mosca::image>& norm_flat,
+(mosca::image& master_flat_d, 
+ std::unique_ptr<mosca::image>& norm_flat,
  cpl_frameset * frameset, const char * flat_tag, 
  const char * master_screen_flat_tag, const char * master_norm_flat_tag, 
  cpl_parameterlist * parlist, cpl_propertylist * qc_list)
@@ -2171,13 +2206,13 @@ int vimos_calib_flats_save
     cpl_propertylist_append(save_header, qc_list);
 
     /* Saving regular flat */
-    cpl_image_turn(master_flat_d->get_cpl_image(), -1);
-    cpl_image_turn(master_flat_d->get_cpl_image_err(), -1);
-    dfs_save_image(frameset, master_flat_d->get_cpl_image(), 
+    cpl_image_turn(master_flat_d.get_cpl_image(), -1);
+    cpl_image_turn(master_flat_d.get_cpl_image_err(), -1);
+    dfs_save_image(frameset, master_flat_d.get_cpl_image(), 
                    master_screen_flat_tag, save_header, parlist, 
                    recipe_name, version);
-    dfs_save_image_ext(master_flat_d->get_cpl_image_err(), 
-                       master_screen_flat_tag, NULL);
+    dfs_save_image_ext_name(master_flat_d.get_cpl_image_err(),
+                       master_screen_flat_tag, NULL, "ERROR");
 
     if(cpl_error_get_code() != CPL_ERROR_NONE)
     {
@@ -2193,8 +2228,8 @@ int vimos_calib_flats_save
         dfs_save_image(frameset, norm_flat->get_cpl_image(), 
                        master_norm_flat_tag, save_header, parlist, 
                        recipe_name, version);
-        dfs_save_image_ext(norm_flat->get_cpl_image_err(), 
-                           master_norm_flat_tag, NULL);
+        dfs_save_image_ext_name(norm_flat->get_cpl_image_err(),
+                           master_norm_flat_tag, NULL, "ERROR");
         if(cpl_error_get_code() != CPL_ERROR_NONE)
         {
             cpl_propertylist_delete(save_header);
@@ -2210,14 +2245,17 @@ int vimos_calib_flats_save
     return 0;
 }
 
-
+static
 cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat, 
                                       cpl_table * slits,
                                       int nx, int ny, int nflats,
                                       mosca::grism_config& grism_cfg,
                                       double alltime, double xwidth,
                                       double ywidth, double gain, 
-                                      double focu_scale)
+                                      double focu_scale,
+									  double qc_resolution,
+									  int qc_nwaves,
+									  double qc_accuracy_nm)
 {
     double     slit_width;
     double     flux, flux_err;
@@ -2246,6 +2284,12 @@ cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat,
     cpl_propertylist_update_double(qc_list,
                                    "ESO PRO WLEN END", grism_cfg.end_wave());
 
+    cpl_propertylist_update_double(qc_list,
+    							idp_input_screen_flat_resolution, qc_resolution);
+    cpl_propertylist_update_int(qc_list,
+    							idp_input_screen_flat_nwave, qc_nwaves);
+    cpl_propertylist_update_double(qc_list,
+    							idp_input_screen_flat_accuracy, qc_accuracy_nm);
 
     /*
      * QC1 parameters
@@ -2293,4 +2337,31 @@ cpl_propertylist * vimos_calib_flat_qc(mosca::image& master_flat,
     return qc_list;
 }
 
+
+static bool get_has_reference_slits(const cpl_propertylist * l){
+
+    cpl_propertylist * ref_slits = cpl_propertylist_new();
+    cpl_propertylist_copy_property_regexp(ref_slits, l, "ESO INS REF", 0);
+    const bool has_reference_slits = (cpl_propertylist_get_size(ref_slits) > 0);
+    cpl_propertylist_delete(ref_slits);
+
+    return has_reference_slits;
+}
+
+static bool
+get_has_curved_slits(const cpl_propertylist * l){
+
+    const char * tag = "ESO INS ARC NO";
+
+    const int n_c_slits = cpl_propertylist_get_int(l, tag);
+
+    if(cpl_error_get_code()){
+        cpl_error_reset();
+        cpl_msg_warning(cpl_func, "Unable to extract %s, assuming no curved apertures");
+        return false;
+    }
+
+    return n_c_slits > 0;
+}
+
 /**@}*/
