@@ -31,6 +31,7 @@
 
 #include <cmath>
 #include <functional>
+#include <sstream>
 #include "vimos_flat_normalise.h"
 #include "moses.h"
 #include "image_smooth.h"
@@ -249,10 +250,13 @@ int vimos::flat_normaliser::mos_normalise
         
         std::vector<float> slit_spa_norm_profile;
         std::vector<float> slit_disp_norm_profile;
+	// disp_smooth_radius_aver is fixed at -1 for now,
+	// which will skip the second smoothing step in mosca
+	// that is used in FORS.
         mosca::image normslit = mosca::image_normalise_spa_local(im_exslit_orig,
                                       slit_mask_im_mos,
                                       final_spa_smooth_radius, disp_smooth_radius,
-                                      spa_fit_polyorder, disp_fit_nknots, 
+                                      -1, spa_fit_polyorder, disp_fit_nknots, 
                                       fit_threshold, normalise_spa_local,
                                       slit_spa_norm_profile,
                                       slit_disp_norm_profile);
