@@ -2380,17 +2380,17 @@ double get_undeviated_wlen(const cpl_propertylist * science_header){
     return to_ret;
 }
 
-bool is_posang_valid(const cpl_propertylist * plist, double & posang){
+bool is_posang_present(const cpl_propertylist * plist){
 
-    posang = cpl_propertylist_get_double(plist, "ESO ADA POSANG");
+    double posang = cpl_propertylist_get_double(plist, "ESO ADA POSANG");
 
     if(cpl_error_get_code()){
+        cpl_msg_warning(cpl_func, "ADA.POSANG is not present");
         cpl_error_reset();
-        posang = -1;
         return false;
     }
 
-    return posang == 0.0 || posang == 90.0;
+    return true;
 }
 
 #define MAX_COLNAME      (80)
@@ -2450,12 +2450,7 @@ void vimos_science_set_object_coord(cpl_table * objects,
         return;
     }
 
-    double posang = 0;
-    if(!is_posang_valid(science_header, posang)){
-        cpl_msg_warning(cpl_func, "ADA.POSANG %f is not allowed in VIMOS MOS, "
-                "object RA/DEC calculation is disabled", posang);
-        return;
-    }
+    if(!is_posang_present(science_header)) return;
 
     mosca::slit_trace_distortion spa_dist(polytraces);
     nobjects = 0;
