@@ -40,6 +40,7 @@
 
 #include "vmtable.h"
 #include "vmifutable.h"
+#include "cpl.h"
 
 
 /*
@@ -50,7 +51,7 @@ VimosIfuFiber *newIfuFiber(void)
 {
  VimosIfuFiber *newFiber;
   /* allocate memory for IFU Fiber */
-  newFiber = (VimosIfuFiber *) pil_malloc(sizeof(VimosIfuFiber));
+  newFiber = (VimosIfuFiber *) cpl_malloc(sizeof(VimosIfuFiber));
 
   /* check if space was allocated */
   if (newFiber == NULL) {
@@ -92,7 +93,7 @@ void deleteIfuFiber(VimosIfuFiber *fiber)
     /* get address of next fiber */
     nextFiber = tmpFiber->next;
     /* free current object */
-    pil_free(tmpFiber);
+    cpl_free(tmpFiber);
     /* next one to process */
     tmpFiber = nextFiber;
   }
@@ -106,7 +107,7 @@ VimosIfuSlit *newIfuSlit()
 {
   VimosIfuSlit *newSlit;
   /* allocate memory for IfuSlit */
-  newSlit = (VimosIfuSlit *) pil_malloc(sizeof(VimosIfuSlit));
+  newSlit = (VimosIfuSlit *) cpl_malloc(sizeof(VimosIfuSlit));
   
   /* check if space was allocated */
   if (newSlit == NULL) {
@@ -143,7 +144,7 @@ void deleteIfuSlit(VimosIfuSlit *ifuSlit)
     /* get address of next IFU slit */
     nextIfuSlit = tmpIfuSlit->next;
     /* free current IFU slit */
-    pil_free(tmpIfuSlit);
+    cpl_free(tmpIfuSlit);
     /* next one to process */
     tmpIfuSlit = nextIfuSlit;
   }
@@ -157,7 +158,7 @@ VimosIfuQuad *newIfuQuad()
 {
   VimosIfuQuad *ifuQuad;
     /* allocate memory for ifuQuad */
-  ifuQuad = (VimosIfuQuad *) pil_malloc(sizeof(VimosIfuQuad));
+  ifuQuad = (VimosIfuQuad *) cpl_malloc(sizeof(VimosIfuQuad));
   
   /* check if space was allocated */
   if (ifuQuad == NULL) {
@@ -200,7 +201,7 @@ void deleteIfuQuad(VimosIfuQuad *ifuQuad)
     /* get address of next IFU quadrant */
     nextIfuQuad = tmpIfuQuad->next;
     /* free current IFU quadrant */
-    pil_free(tmpIfuQuad);
+    cpl_free(tmpIfuQuad);
     /* next one to process */
     tmpIfuQuad = nextIfuQuad;
   }
@@ -215,7 +216,7 @@ VimosIfuTable *newIfuTable()
   VimosIfuTable *ifuTab;
 
   /* allocate new VimosIfuTable */
-  ifuTab = (VimosIfuTable *) pil_malloc(sizeof(VimosIfuTable));
+  ifuTab = (VimosIfuTable *) cpl_malloc(sizeof(VimosIfuTable));
  
   /* check if space was allocated */
   if (ifuTab == NULL) {
@@ -228,7 +229,7 @@ VimosIfuTable *newIfuTable()
   ifuTab->descs = newStringDescriptor("ESO PRO TABLE", "IFU", "");
   if (ifuTab->descs == NULL) {
     /* cleanup */
-    pil_free(ifuTab);
+    cpl_free(ifuTab);
     pilMsgError("newIfuTable","The function newStringDescriptor has returned NULL");
     return(NULL);
   }
@@ -500,9 +501,9 @@ VimosBool readFitsIfuTable(VimosIfuTable *ifuTable, fitsfile *fptr)
   }
 
  /* allocate space for the column labels */
-  ttype = (char **) pil_malloc(nCols*sizeof(char *));
+  ttype = (char **) cpl_malloc(nCols*sizeof(char *));
   for (i = 0; i < nCols; i++) {
-    ttype[i] = (char *) pil_malloc(FLEN_VALUE*sizeof(char));
+    ttype[i] = (char *) cpl_malloc(FLEN_VALUE*sizeof(char));
 
     /* check if space was allocated */
     if (ttype[i] == NULL) {
@@ -754,7 +755,7 @@ VimosBool readFitsIfuTable(VimosIfuTable *ifuTable, fitsfile *fptr)
   /* free the memory for the column labels */
   for (ii = 0; ii < 3; ii++)
      {
-      pil_free( ttype[ii] );
+      cpl_free( ttype[ii] );
      }
  
   return (VM_TRUE);
@@ -808,13 +809,13 @@ VimosBool writeFitsIfuTable(VimosIfuTable *ifuTable, fitsfile *fptr)
   /* allocate space for the column labels */
   for (i = 0; i <= 8; i++)
      {
-      ttype[i] = (char *) pil_malloc(FLEN_VALUE);  /* max label length = 69 */
+      ttype[i] = (char *) cpl_malloc(FLEN_VALUE);  /* max label length = 69 */
       /* check if space was allocated */
       if (ttype[i] == NULL) {
 	pilMsgError("writeFitsIfuTable","Allocation Error");
 	return (VM_FALSE);
       }
-      tform[i] = (char *) pil_malloc(FLEN_VALUE);
+      tform[i] = (char *) cpl_malloc(FLEN_VALUE);
       /* check if space was allocated */
       if (tform[i] == NULL) {
 	pilMsgError("writeFitsIfuTable","Allocation Error");
