@@ -49,6 +49,7 @@
 #include "vmdistmodels.h"
 #include "vmmossphotcalib.h"
 #include "vmimgutils.h"
+#include "cpl.h"
 
 
 static int
@@ -60,8 +61,8 @@ polint2(float xa[], float ya[], int nDat, float x, float *y, float *dy)
   float *c,*d;
 
   dif=fabs(x-xa[0]);
-  c = (float *) pil_calloc(nDat, sizeof(float));
-  d = (float *) pil_calloc(nDat, sizeof(float));
+  c = (float *) cpl_calloc(nDat, sizeof(float));
+  d = (float *) cpl_calloc(nDat, sizeof(float));
   for (i=0; i<nDat; i++) 
   {
     if ( (dift=fabs(x-xa[i])) < dif) 
@@ -91,8 +92,8 @@ polint2(float xa[], float ya[], int nDat, float x, float *y, float *dy)
     }
     *y += (*dy=(2*ns < (nDat-m) ? c[ns+1] : d[ns--]));
   }
-  pil_free(d);
-  pil_free(c);
+  cpl_free(d);
+  cpl_free(c);
   return EXIT_SUCCESS;
 }
 
@@ -106,12 +107,12 @@ readCalSphotModel(VimosDescriptor *desc, int modelDeg)
   double    *coeffs;
   int        i;
 
-  coeffs = pil_malloc((modelDeg+1)*sizeof(double)) ;
+  coeffs = cpl_malloc((modelDeg+1)*sizeof(double)) ;
   for (i = 0; i <= modelDeg; i++)
   {
     if (readDoubleDescriptor(desc, pilTrnGetKeyword("SphotModel", i), 
 			     &dValue, comment) == VM_FALSE) {
-      pil_free(coeffs);
+      cpl_free(coeffs);
       coeffs = NULL;
       cpl_msg_error(modName, "Cannot read descriptor %s", 
 		  pilTrnGetKeyword("SphotModel", i)); 
